%define enable_atlas 0


%define module	numpy
%define name	python-%{module}
%define epoch 	1

# disable this for bootstrapping nose and sphinx
# there is no python3-nose yet
%define enable_tests 1
%define enable_doc 1

#uncomment next line for a release candidate or a beta
#define relc rc1

#release to bump
%define rel 1

Summary:	A fast multidimensional array facility for Python
Name:		python-%{module}
Version:	1.11.2
Epoch:		%{epoch}
Release:	%mkrel %{?relc:0.%relc.}%{rel}
License:	BSD
Group:		Development/Python
Url: 		http://numpy.scipy.org
Source0:	http://download.sourceforge.net/numpy/numpy-%{version}%{?relc}.tar.gz
Provides:	f2py
Obsoletes:	f2py
%if %enable_atlas
BuildRequires:	libatlas-devel
%else
BuildRequires:	blas-devel
%endif
BuildRequires:	lapack-devel
BuildRequires:	gcc-gfortran >= 4.0
%if %enable_doc
BuildRequires:	python-sphinx >= 1.0
BuildRequires:  python-sphinx_rtd_theme
BuildRequires:	python-matplotlib
BuildRequires:	python3-sphinx >= 1.0
BuildRequires:  python3-sphinx_rtd_theme
BuildRequires:	python3-matplotlib
%endif
%if %enable_tests
BuildRequires:	python-nose
BuildRequires:	python3-nose
%endif
BuildRequires:	pkgconfig(python)
BuildRequires:	python-cython
BuildRequires:	python-setuptools
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools

Obsoletes:	python-numeric < 24.2-8
Provides:	python-numeric

%description
Numpy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays. Numpy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type.

Numpy also provides facilities for basic linear algebra routines,
basic Fourier transforms, and random number generation.

%package devel
Summary:	Numpy headers
Group:		Development/Python
Requires:	%{name} = %{epoch}:%{version}-%{release}
Obsoletes:  python-numeric-devel < 2.8
Provides:   python-numeric-devel = %epoch:%version-%release

%description devel
This package contains header files need to develop modules 
in C and Fortran that can interact with Numpy

%package f2py
Summary:        f2py for numpy
Group:          Development/Python
Requires:       %{name} = %{epoch}:%{version}-%{release}
Requires:       python-devel
Provides:       f2py = %{version}-%{release}
Obsoletes:      f2py <= 2.45.241_1927

%description f2py
This package includes a version of f2py that works properly with NumPy.

%package -n python3-numpy
Summary:    A fast multidimensional array facility for Python3
Group:		Development/Python
License:    BSD

%description -n python3-numpy
Numpy is a general-purpose array-processing package designed to
efficiently manipulate large multi-dimensional arrays of arbitrary
records without sacrificing too much speed for small multi-dimensional
arrays. Numpy is built on the Numeric code base and adds features
introduced by numarray as well as an extended C-API and the ability to
create arrays of arbitrary type.

Numpy also provides facilities for basic linear algebra routines,
basic Fourier transforms, and random number generation.

%package -n python3-numpy-devel
Summary:    Numpy headers
Group:		Development/Python
Requires:   python3-numpy = %{epoch}:%{version}-%{release}
Obsoletes:  python3-numeric-devel < 2.8
Provides:   python3-numeric-devel = %epoch:%version-%release

%description -n python3-numpy-devel
This package contains header files need to develop modules 
in C and Fortran that can interact with Numpy

%package -n python3-numpy-f2py
Summary:        f2py for numpy
Group:          Development/Python
Requires:       python3-numpy = %{epoch}:%{version}-%{release}
Requires:       python3-devel
Provides:       python3-f2py = %{version}-%{release}
Obsoletes:      python3-f2py <= 2.45.241_1927

%description -n python3-numpy-f2py
This package includes a version of f2py that works properly with NumPy.

%prep
%setup -q -n %{module}-%{version}%{?relc}
# workaround for rhbz#849713
# http://mail.scipy.org/pipermail/numpy-discussion/2012-July/063530.html
rm numpy/distutils/command/__init__.py && touch numpy/distutils/command/__init__.py

cp -a . %{py3dir}

%build
pushd %{py3dir}
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags} -fPIC -O3" \
    %{__python3} setup.py build
popd

#CFLAGS="%{optflags} -fPIC -O3" PYTHONDONTWRITEBYTECODE= %{__python2} setup.py config_fc --fcompiler=gnu95 build
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags} -fPIC -O3" \
    %{__python2} setup.py build

%if %enable_doc
pushd doc
export PYTHONPATH=`dir -d ../build/lib.linux*`
%make html
popd
%endif

%install
# first install python3 so the binaries are overwritten by the python2 ones
pushd %{py3dir}
#%{__python2} setup.py install -O1 --skip-build --root %{buildroot}
# skip-build currently broken, this works around it for now
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags} -fPIC -O3" \
    %{__python3} setup.py install --root %{buildroot}
pushd %{buildroot}%{_bindir} &> /dev/null
popd &> /dev/null
popd

# skip-build currently broken, this works around it for now
env ATLAS=%{_libdir} FFTW=%{_libdir} BLAS=%{_libdir} \
    LAPACK=%{_libdir} CFLAGS="%{optflags} -fPIC -O3" \
    %{__python2} setup.py install --root %{buildroot}
pushd %{buildroot}%{_bindir} &> /dev/null
# symlink for anyone who was using f2py.numpy
ln -s f2py2 f2py.numpy
popd &> /dev/null
install -D -p -m 0644 doc/f2py/f2py.1 %{buildroot}%{_mandir}/man1/f2py.1

# Remove doc files that should be in %doc:
%__rm -f %{buildroot}%{py_platsitedir}/%{module}/COMPATIBILITY
%__rm -f %{buildroot}%{py_platsitedir}/%{module}/*.txt
%__rm -f %{buildroot}%{py_platsitedir}/%{module}/site.cfg.example

%check
%if %enable_tests

# Don't run tests from within main directory to avoid importing the uninstalled numpy stuff:
pushd doc &> /dev/null
PYTHONPATH="%{buildroot}%{py_platsitedir}" %{__python2} -c "import pkg_resources, numpy; numpy.test()"
popd &> /dev/null

pushd doc &> /dev/null
PYTHONPATH="%{buildroot}%{python3_sitearch}" %{__python3} -c "import pkg_resources, numpy ; numpy.test()"
popd &> /dev/null
%endif

%files
%license LICENSE.txt
%doc THANKS.txt site.cfg.example
%if %enable_doc
%doc doc/build/html
%endif
%dir %{python2_sitearch}/%{module}
%{python2_sitearch}/%{module}/*.py*
%{python2_sitearch}/%{module}/core/ 
%{python2_sitearch}/%{module}/compat/
%{python2_sitearch}/%{module}/doc/
%exclude %{python2_sitearch}/%{module}/core/include/
%{python2_sitearch}/%{module}/fft/
%{python2_sitearch}/%{module}/lib/
%{python2_sitearch}/%{module}/linalg/
%{python2_sitearch}/%{module}/ma/
%{python2_sitearch}/%{module}/matrixlib/
%{python2_sitearch}/%{module}/polynomial/
%{python2_sitearch}/%{module}/random/
%exclude %{python2_sitearch}/%{module}/random/randomkit.h
%{python2_sitearch}/%{module}/testing/
%{python2_sitearch}/%{module}/tests/ 
%{python2_sitearch}/%{module}-*.egg-info
%{python2_sitearch}/%{module}/distutils/

%files devel
%{python2_sitearch}/%{module}/core/include/
%{python2_sitearch}/%{module}/random/randomkit.h

%files f2py
%doc doc/f2py/*.txt
%{_mandir}/man1/f2py.*
%{_bindir}/f2py2
%{_bindir}/f2py.numpy
%{python2_sitearch}/%{module}/f2py

%files -n python3-numpy
%license LICENSE.txt
%doc THANKS.txt site.cfg.example
%{python3_sitearch}/%{module}/__pycache__/*
%dir %{python3_sitearch}/%{module}
%{python3_sitearch}/%{module}/*.py*
%{python3_sitearch}/%{module}/core
%{python3_sitearch}/%{module}/distutils
%{python3_sitearch}/%{module}/doc/
%{python3_sitearch}/%{module}/fft
%{python3_sitearch}/%{module}/lib
%{python3_sitearch}/%{module}/linalg
%{python3_sitearch}/%{module}/ma
%{python3_sitearch}/%{module}/random
%{python3_sitearch}/%{module}/testing
%{python3_sitearch}/%{module}/tests
%{python3_sitearch}/%{module}/compat
%{python3_sitearch}/%{module}/matrixlib
%{python3_sitearch}/%{module}/polynomial
%{python3_sitearch}/%{module}-*.egg-info
%exclude %{python3_sitearch}/%{module}/core/include/
%exclude %{python3_sitearch}/%{module}/random/randomkit.h

%files -n python3-numpy-f2py
%{_bindir}/f2py3
%{python3_sitearch}/%{module}/f2py

%files -n python3-numpy-devel
%{python3_sitearch}/%{module}/core/include/
%{python3_sitearch}/%{module}/random/randomkit.h



%changelog
* Wed Oct 26 2016 luigiwalser <luigiwalser> 1:1.11.2-1.mga6
+ Revision: 1063531
- 1.11.2

* Sat Sep 10 2016 luigiwalser <luigiwalser> 1:1.11.1-1.mga6
+ Revision: 1051262
- 1.11.1

* Sun Apr 24 2016 joequant <joequant> 1:1.11.0-1.mga6
+ Revision: 1005833
- update to 1.11.0

* Mon Jan 18 2016 luigiwalser <luigiwalser> 1:1.10.4-1.mga6
+ Revision: 925552
- 1.10.4

* Sun Nov 08 2015 tv <tv> 1:1.10.0-1.mga6
+ Revision: 898697
- new release

* Sat Oct 10 2015 tv <tv> 1:1.10.0-0.rc1.3.mga6
+ Revision: 889146
- BR python3-sphinx_rtd_theme
- unbootstrap

* Thu Oct 08 2015 tv <tv> 1:1.10.0-0.rc1.2.mga6
+ Revision: 887261
- bootstrap
- rebuild for python 3.5

* Sun Sep 27 2015 wally <wally> 1:1.10.0-0.rc1.1.mga6
+ Revision: 884189
- fix release tag

* Sun Sep 27 2015 joequant <joequant> 1:1.10.0-0.rc1.mga6
+ Revision: 884159
- fix bindir name
- upgrade to 1.10.0rc1
- update to 1.9.3 / python 3.5

* Tue Jun 30 2015 joequant <joequant> 1:1.9.2-1.mga6
+ Revision: 848427
- upgrade to 1.9.2

* Wed Oct 15 2014 umeabot <umeabot> 1:1.8.2-4.mga5
+ Revision: 749676
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1:1.8.2-3.mga5
+ Revision: 726911
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1:1.8.2-2.mga5
+ Revision: 688185
- Mageia 5 Mass Rebuild

* Fri Aug 15 2014 philippem <philippem> 1:1.8.2-1.mga5
+ Revision: 662701
- update to 1.8.2

* Sat May 31 2014 pterjan <pterjan> 1:1.8.1-3.mga5
+ Revision: 628852
- Rebuild for new Python

* Wed Apr 09 2014 philippem <philippem> 1:1.8.1-2.mga5
+ Revision: 613118
- move f2py and distutils into main package, let only headers in devel packages

* Sun Mar 30 2014 philippem <philippem> 1:1.8.1-1.mga5
+ Revision: 610377
- update to 1.8.1

* Wed Feb 19 2014 philippem <philippem> 1:1.8.0-2.mga5
+ Revision: 594840
- Fix CVE-2014-1858, CVE-2014-1859 (mga#12814)

* Fri Dec 27 2013 philippem <philippem> 1:1.8.0-1.mga4
+ Revision: 560969
- Update to 1.8.0

* Tue Oct 22 2013 umeabot <umeabot> 1:1.7.1-3.mga4
+ Revision: 543984
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1:1.7.1-2.mga4
+ Revision: 498975
- Rebuild to add different pythonegg provides for python 2 and 3

  + philippem <philippem>
    - cleaning spec

* Thu Jun 27 2013 philippem <philippem> 1:1.7.1-1.mga4
+ Revision: 447337
- new upstream
- Python 3 package

* Sun Jan 13 2013 umeabot <umeabot> 1:1.6.2-2.mga3
+ Revision: 379178
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Sep 08 2012 philippem <philippem> 1:1.6.2-1.mga3
+ Revision: 290081
- New upstream release 1.6.2

* Fri Sep 16 2011 philippem <philippem> 1:1.6.1-2.mga2
+ Revision: 144223
-update to new upstream

* Mon Jul 04 2011 ahmad <ahmad> 1:1.6.0-1.mga2
+ Revision: 118035
- Update to 1.6.0

* Tue May 03 2011 ahmad <ahmad> 1:1.5.1-5.mga1
+ Revision: 94531
- Fix python-numeric obosletes
- Make the python-numeric Provides generic

* Fri Apr 29 2011 dmorgan <dmorgan> 1:1.5.1-4.mga1
+ Revision: 93481
- Obsoletes/Provides python-numeric

* Mon Jan 17 2011 pterjan <pterjan> 1:1.5.1-3.mga1
+ Revision: 20951
- Fix extensiosn linkage

  + misc <misc>
    - use a hack to make it compile until we can properly debug this
      ( ie, after the bootstrap phase )

  + ahmad <ahmad>
    - rebuild for python-2.7

* Thu Jan 13 2011 ahmad <ahmad> 1:1.5.1-2.mga1
+ Revision: 8284
- drop %%py_requires macro and use BR python-devel
- imported package python-numpy

